import unittest

class TestFormatProxy(unittest.TestCase):
    def test_format_proxy(self):
        # self.assertEqual(expected, format_proxy(scheme, username, password, hostname, port))
        assert False # TODO: implement your test here

class TestAudioAddictBackend(unittest.TestCase):
    def test___init__(self):
        # audio_addict_backend = AudioAddictBackend(config, audio)
        assert False # TODO: implement your test here

class TestAudioAddictLibrary(unittest.TestCase):
    def test_browse(self):
        # audio_addict_library = AudioAddictLibrary()
        # self.assertEqual(expected, audio_addict_library.browse(uri))
        assert False # TODO: implement your test here

    def test_find_exact(self):
        # audio_addict_library = AudioAddictLibrary()
        # self.assertEqual(expected, audio_addict_library.find_exact(query, uris))
        assert False # TODO: implement your test here

    def test_lookup(self):
        # audio_addict_library = AudioAddictLibrary()
        # self.assertEqual(expected, audio_addict_library.lookup(uri))
        assert False # TODO: implement your test here

    def test_refresh(self):
        # audio_addict_library = AudioAddictLibrary()
        # self.assertEqual(expected, audio_addict_library.refresh(uri))
        assert False # TODO: implement your test here

    def test_search(self):
        # audio_addict_library = AudioAddictLibrary()
        # self.assertEqual(expected, audio_addict_library.search(query, uris))
        assert False # TODO: implement your test here

class TestAudioAddictPlayback(unittest.TestCase):
    def test_change_track(self):
        # audio_addict_playback = AudioAddictPlayback()
        # self.assertEqual(expected, audio_addict_playback.change_track(track))
        assert False # TODO: implement your test here

if __name__ == '__main__':
    unittest.main()
