import unittest

class TestAudioAddict(unittest.TestCase):
    def test___init__(self):
        # audio_addict = AudioAddict(username, password, quality, difm, radiotunes, rockradio, jazzradio, frescaradio, proxy)
        assert False # TODO: implement your test here

    def test_channel(self):
        # audio_addict = AudioAddict(username, password, quality, difm, radiotunes, rockradio, jazzradio, frescaradio, proxy)
        # self.assertEqual(expected, audio_addict.channel(identifier))
        assert False # TODO: implement your test here

    def test_channels(self):
        # audio_addict = AudioAddict(username, password, quality, difm, radiotunes, rockradio, jazzradio, frescaradio, proxy)
        # self.assertEqual(expected, audio_addict.channels(radiostation))
        assert False # TODO: implement your test here

    def test_flush(self):
        # audio_addict = AudioAddict(username, password, quality, difm, radiotunes, rockradio, jazzradio, frescaradio, proxy)
        # self.assertEqual(expected, audio_addict.flush())
        assert False # TODO: implement your test here

    def test_radiostations(self):
        # audio_addict = AudioAddict(username, password, quality, difm, radiotunes, rockradio, jazzradio, frescaradio, proxy)
        # self.assertEqual(expected, audio_addict.radiostations(radiostation))
        assert False # TODO: implement your test here

if __name__ == '__main__':
    unittest.main()
