import unittest

class TestUnparseUri(unittest.TestCase):
    def test_unparse_uri(self):
        # self.assertEqual(expected, unparse_uri(variant, identifier))
        assert False # TODO: implement your test here

class TestParseUri(unittest.TestCase):
    def test_parse_uri(self):
        # self.assertEqual(expected, parse_uri(uri))
        assert False # TODO: implement your test here

class TestChannelToRef(unittest.TestCase):
    def test_channel_to_ref(self):
        # self.assertEqual(expected, channel_to_ref(channel))
        assert False # TODO: implement your test here

class TestRadiostationToRef(unittest.TestCase):
    def test_radiostation_to_ref(self):
        # self.assertEqual(expected, radiostation_to_ref(radiostation))
        assert False # TODO: implement your test here

if __name__ == '__main__':
    unittest.main()
